@@ -1,16 +1,18 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-
+import logging
 import json
 from . import webservice
-
+from .exceptions import WQDataNotFoundError, WQServiceIsDownError
 
 UA = 'isbntools (gzip)'
 
 OUT_OF_SERVICE = 'Temporarily out of service'
 BOOK_NOT_FOUND = 'No results match your search'
 
+logger = logging.getLogger(__name__)
+
 
 class WEBQuery(object):
     """
@@ -21,6 +23,7 @@ class WEBQuery(object):
         """
         Initializer & call webservice
         """
+        self.url = service_url
         self.data = webservice.query(service_url, ua)
 
     def check_data(self):
@@ -28,11 +31,14 @@ class WEBQuery(object):
         Checks the data & handle errors
         """
         if self.data == '{}':
-            raise Exception('Data not found!')
+            logger.warning('WQDataNotFoundError for %s' % self.url)
+            raise WQDataNotFoundError(self.url)
         if BOOK_NOT_FOUND in self.data:
-            raise Exception('Data not found!')
+            logger.warning('WQDataNotFoundError for %s' % self.url)
+            raise WQDataNotFoundError(self.url)
         if OUT_OF_SERVICE in self.data:
-            raise Exception('Temporarily out of service. Try later!')
+            logger.critical('WQServiceIsDownError for %s' % self.url)
+            raise WQServiceIsDownError(self.url)
 
     def parse_data(self, parser=json.loads):
         """
